==> nextcloud-app-contacts-4.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/ia.js <==
OC.L10N.register(
    "contacts",
    {
    "Details" : "Detalios",
    "All contacts" : "Tote contactos",
    "Contacts" : "Contactos",
    "Download" : "Discargar",
    "Groups" : "Gruppos",
    "Group name" : "Nomine del gruppo",
    "Rename" : "Renominar",
    "Enabled" : "Activate",
    "Delete" : "Deler",
    "Copy link" : "Copiar ligamine",
    "Share with users or groups" : "Compartir con usatores o gruppos",
    "can edit" : "pote modificar",
    "First name" : "Prime nomine",
    "Last name" : "Ultime nomine",
    "Display name" : "Monstrar nomine",
    "Invalid image" : "Imagine invalide",
    "Name" : "Nomine",
    "Title" : "Titulo",
    "Cancel" : "Cancellar",
    "New contact" : "Nove contacto",
    "Close" : "Clauder",
    "Import" : "Importar",
    "Not grouped" : "Non gruppate",
    "Email" : "E-posta",
    "Nickname" : "Pseudonymo",
    "Detailed name" : "Nomine detaliate",
    "Additional names" : "Nomines additional",
    "Prefix" : "Prefixo",
    "Suffix" : "Suffixo",
    "Notes" : "Notas",
    "Website" : "Sito web",
    "Location" : "Loco",
    "Federated Cloud ID" : "ID del Nube Federate",
    "Home" : "Domo",
    "Work" : "Travalio",
    "Other" : "Altere",
    "Address" : "Adresse",
    "Post office box" : "Cassa postal",
    "City" : "Citate",
    "State or province" : "Stato o provincia",
    "Postal code" : "Codice postal",
    "Country" : "Pais",
    "Birthday" : "Anniversario de nativitate",
    "Anniversary" : "Anniversario de evento",
    "Date of death" : "Data de morte",
    "Instant messaging" : "Messageria instantanee",
    "Phone" : "Phono",
    "Mobile" : "Mobile",
    "Fax" : "Fax",
    "Fax home" : "Fax a domicilio",
    "Fax work" : "Fax a travalio",
    "Pager" : "Pager",
    "Voice" : "Voce",
    "Social network" : "Medios Social",
    "Relative" : "Relative",
    "None" : "Nulle",
    "Unknown" : "Incognite"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-contacts-5.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/ia.js <==
OC.L10N.register(
    "contacts",
    {
    "Details" : "Detalios",
    "All contacts" : "Tote contactos",
    "Contacts" : "Contactos",
    "Download" : "Discargar",
    "Send email" : "Inviar message de e-posta",
    "Groups" : "Gruppos",
    "Group name" : "Nomine del gruppo",
    "Rename" : "Renominar",
    "Enabled" : "Activate",
    "Delete" : "Deler",
    "Copy link" : "Copiar ligamine",
    "Share with users or groups" : "Compartir con usatores o gruppos",
    "can edit" : "pote modificar",
    "First name" : "Prime nomine",
    "Last name" : "Ultime nomine",
    "Display name" : "Monstrar nomine",
    "Password protection" : "Password protection",
    "Save" : "Salveguardar",
    "Description" : "Description",
    "Invalid image" : "Imagine invalide",
    "Name" : "Nomine",
    "Title" : "Titulo",
    "Cancel" : "Cancellar",
    "New contact" : "Nove contacto",
    "Pending" : "Pendente",
    "Close" : "Clauder",
    "Import" : "Importar",
    "Not grouped" : "Non gruppate",
    "User" : "User",
    "Group" : "Gruppo",
    "Email" : "E-posta",
    "Owner" : "Owner",
    "Users" : "Usatores",
    "Nickname" : "Pseudonymo",
    "Detailed name" : "Nomine detaliate",
    "Additional names" : "Nomines additional",
    "Prefix" : "Prefixo",
    "Suffix" : "Suffixo",
    "Notes" : "Notas",
    "Website" : "Sito web",
    "Location" : "Loco",
    "Federated Cloud ID" : "ID del Nube Federate",
    "Home" : "Domo",
    "Work" : "Travalio",
    "Other" : "Altere",
    "Address" : "Adresse",
    "Post office box" : "Cassa postal",
    "City" : "Citate",
    "State or province" : "Stato o provincia",
    "Postal code" : "Codice postal",
    "Country" : "Pais",
    "Birthday" : "Anniversario de nativitate",
    "Anniversary" : "Anniversario de evento",
    "Date of death" : "Data de morte",
    "Instant messaging" : "Messageria instantanee",
    "Phone" : "Phono",
    "Mobile" : "Mobile",
    "Fax" : "Fax",
    "Fax home" : "Fax a domicilio",
    "Fax work" : "Fax a travalio",
    "Pager" : "Pager",
    "Voice" : "Voce",
    "Social network" : "Medios Social",
    "Relative" : "Relative",
    "None" : "Nulle",
    "Unknown" : "Incognite"
},
"nplurals=2; plural=(n != 1);");
